"use strict";

var _jsdom = _interopRequireDefault(require("jsdom"));
var _AllCountries = _interopRequireDefault(require("../AllCountries"));
var _utils = _interopRequireDefault(require("../utils"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
describe('utils', function () {
  it('arraysEqual', function () {
    var a = [1, 2, 3];
    var b = a;
    expect(_utils["default"].arraysEqual(a, b)).toBeTruthy();
    a = [1, 2, 3];
    b = null;
    expect(_utils["default"].arraysEqual(a, b)).toBeFalsy();
    a = [1, 2, 3];
    b = [2, 1, 4, 5];
    expect(_utils["default"].arraysEqual(a, b)).toBeFalsy();
    a = ['1', '2', '3'];
    b = ['3', '1', '2'];
    expect(_utils["default"].arraysEqual(a, b)).toBeFalsy();
  });
  it('shallowEquals', function () {
    var a = [1, 2, 3];
    var b = a;
    expect(_utils["default"].shallowEquals(a, b)).toBeTruthy();
    a = {
      x: ['1', '2', '3'],
      y: 'abc'
    };
    b = {
      x: ['1', '2', '3'],
      y: 'abc'
    };
    expect(_utils["default"].shallowEquals(a, b)).toBeTruthy();
    a = {
      x: ['1', '2', '3'],
      y: ['1', '3', '4']
    };
    b = {
      x: ['1', '2', '3'],
      y: ['4', '2']
    };
    expect(_utils["default"].shallowEquals(a, b)).toBeFalsy();
    a = {
      a: 1,
      b: 2
    };
    b = Object.create(a);
    b.c = 3;
    expect(_utils["default"].shallowEquals(a, b)).toBeFalsy();
  });
  it('trim', function () {
    expect(_utils["default"].trim(undefined)).toBe('');
    var str = ' Hello World   ';
    expect(_utils["default"].trim(str)).toBe('Hello World');
  });
  it('isNumeric', function () {
    var num = 1.2;
    expect(_utils["default"].isNumeric(num)).toBeTruthy();
  });
  it('retrieveLiIndex', function () {
    var DEFAULT_HTML = "<html><body>\n      <ul id=\"list\">\n        <li class=\"a\">a</li>\n        <li class=\"b\">b</li>\n      </ul>\n    </body></html>";
    var doc = _jsdom["default"].jsdom(DEFAULT_HTML);
    var bListItem = doc.querySelector('.b');
    expect(_utils["default"].retrieveLiIndex(bListItem)).toBe(1);
    var otherListItem = doc.querySelector('.z');
    expect(_utils["default"].retrieveLiIndex(otherListItem)).toBe(-1);
  });
  it('getNumeric', function () {
    var str = 'Hello 1000 World';
    expect(_utils["default"].getNumeric(str)).toBe('1000');
  });
  it('startsWith', function () {
    var str = 'Hello World';
    expect(_utils["default"].startsWith(str, 'H')).toBeTruthy();
  });
  it('isWindow', function () {
    expect(_utils["default"].isWindow(global.window)).toBeTruthy();
  });
  it('getWindow', function () {
    expect(_utils["default"].getWindow(global.window)).toBe(global.window);
  });
  it('getCountryData', function () {
    var result = {
      name: 'Taiwan (台灣)',
      iso2: 'tw',
      dialCode: '886',
      priority: 0,
      areaCodes: null
    };
    expect(_utils["default"].getCountryData(_AllCountries["default"].getCountries())).toStrictEqual({});
    expect(_utils["default"].getCountryData(_AllCountries["default"].getCountries(), undefined, true, true)).toEqual(null);
    expect(_utils["default"].getCountryData(_AllCountries["default"].getCountries(), 'tw')).toEqual(result);
    expect(_utils["default"].getCountryData(_AllCountries["default"].getCountries(), 'zz', true, true)).toBeNull();
    expect(_utils["default"].getCountryData(_AllCountries["default"].getCountries(), 'zz', false, false, function (country) {
      return "".concat(country, "!!");
    })).toStrictEqual({});
  });
  it('findIndex', function () {
    var array = [];
    var predicate = function predicate() {
      return true;
    };
    expect(_utils["default"].findIndex(array, predicate)).toEqual(-1);
    array = [1, 2, 3];
    predicate = function predicate(item) {
      return item === 2;
    };
    expect(_utils["default"].findIndex(array, predicate)).toEqual(1);
    array = [1, 2, 3];
    predicate = function predicate(item) {
      return item === 4;
    };
    expect(_utils["default"].findIndex(array, predicate)).toEqual(-1);
  });
  it('getCursorPositionAfterFormating', function () {
    var previousStringBeforeCursor = '9123';
    var previousString = '912345';
    var nextString = '912345';
    expect(_utils["default"].getCursorPositionAfterFormating(previousStringBeforeCursor, previousString, nextString)).toEqual(4);
    previousStringBeforeCursor = '0912 345';
    previousString = '0912 345 678';
    nextString = '91234678';
    expect(_utils["default"].getCursorPositionAfterFormating(previousStringBeforeCursor, previousString, nextString)).toEqual(5);
    previousStringBeforeCursor = '91234';
    previousString = '91234678';
    nextString = '0912 345 678';
    expect(_utils["default"].getCursorPositionAfterFormating(previousStringBeforeCursor, previousString, nextString)).toEqual(7);
    previousStringBeforeCursor = '(201) 5';
    previousString = '(201) 55-01';
    nextString = '201-5501';
    expect(_utils["default"].getCursorPositionAfterFormating(previousStringBeforeCursor, previousString, nextString)).toEqual(5);
  });
});